
// FindComics.java
// Andrew Davison, February 2014, ad@fivedots.coe.psu.ac.th

/* Use a character or series name or IDs combined with a date (range) to
   find comics and their IDs from the Marvel Rest API
   (http://http://developer.marvel.com/)


   Usage: run FindComics (character|ID(s)|?) (series_title|ID(s)|?) [ year[-year] ]
                                     // ? means "doesn't matter"
   e.g.
     run FindComics spider-man ? 1963

     run FindComics ? "Amazing Spider-man" 1965
     run FindComics ? 1987 1965

     run FindComics 1009382 "1987,454"
     run FindComics 1009382 "1987,454" 1990-2014
                // juggernaut == 1009382
                // 1987,454 == Amazing Spider-Man (1963 - 1998) and (1999 - 2013)


      run FindComics "1009287,1009537" ?
         -- look for a shared appearance of electro and the rhino

     Comic info returned for each matching comic issue:
             ID, title, issue no,
             on-sale date, thumbnail URL pointing to JPG,
             page count, no. of stories,
             titles of stories (including cover title)
    Sorted into on-sale date order.
*/

import java.io.*;
import java.util.*;
import java.awt.image.*;



public class FindComics
{
  private static final String PUBLIC_KEY = "XXXX";
  private static final String PRIVATE_KEY = "XXXX";
     /* You must first register for a free Marvel developer account at
        http://developer.marvel.com/ and obtain a public and private API keys.

        Then edit the constants PUBLIC_KEY and PRIVATE_KEY to be your keys.
     */



  public static void main(String[] args)
  {
    if ((args.length < 2) || (args.length > 3)) {
      System.out.println("Usage: run FindComics (character|ID(s)|?) (series_title|ID(s)|?) [year[-year]]");
      return;
    }

    // prepare the character ID
    String characterID;
    if (args[0].equals("?"))   // not being used
      characterID = null;
    else if (!MarvelUtils.isID(args[0])) {    // user supplied a name string
      System.out.println("Get character ID for \"" + args[0] + "\"");
      characterID = MarvelUtils.lookupCharacterID(args[0], PUBLIC_KEY, PRIVATE_KEY);
    }
    else
      characterID = args[0];
    System.out.println("Using character ID: " + characterID + "\n");


    // prepare the series ID
    String seriesID;
    if (args[1].equals("?"))   // not being used
      seriesID = null;
    else if (!MarvelUtils.isID(args[1])) {    // user supplied a series string
      System.out.println("Get series ID for \"" + args[1] + "\"");
      seriesID = MarvelUtils.lookupSeriesID(args[1], PUBLIC_KEY, PRIVATE_KEY);
    }
    else
      seriesID = args[1];
    System.out.println("Using series ID: " + seriesID + "\n");


    if ((characterID == null) && (seriesID == null)) {
      System.out.println("You must supply at least one character or series as input");
      return;
    }

    // prepare the year info
    int[] yearRange = null;
    if (args.length == 3)
      yearRange = MarvelUtils.getYears(args[2]);     // extract the year (or year range)



    System.out.println("Looking for comics");
    String urlQuery = MarvelUtils.comicsRequest(characterID, seriesID,
                                      yearRange, PUBLIC_KEY, PRIVATE_KEY);

    String response = MarvelUtils.sendQuery(urlQuery);
    MarvelUtils.comicsResults(response, false);
  }   // end of main()


}  // end of FindComics class
