
// GetID.java
// Andrew Davison, February 2014, ad@fivedots.coe.psu.ac.th

/*
   Find the ID for a character name or series name using the Marvel API
   (http://developer.marvel.com/)

   A search for a character will return name, ID, description, and thumbnail URL.
   The name can be a partial string for the start of the name.

   A search for a series will return title, ID, description.
   The series name can be a partial string for the start of the title.


   Multiple matching IDs will be printed, which is especially common
   for series names. They are sorted into start year order.

   Usage: run GetID [series] <name>
   e.g.
     run GetID juggernaut
     run GetID "luke cage"
     run GetID power

     run GetID series "Journey into Mystery"
     run GetID series journey
  
*/

import java.io.*;
import java.util.*;



public class GetID
{
  private static final String PUBLIC_KEY = "XXXX";
  private static final String PRIVATE_KEY = "XXXX";
     /* You must first register for a free Marvel developer account at
        http://developer.marvel.com/ and obtain a public and private API keys.

        Then edit the constants PUBLIC_KEY and PRIVATE_KEY to be your keys.
     */


  public static void main(String[] args)
  {
    if ((args.length < 1) || (args.length > 2))
      System.out.println("Usage: run GetID [series] <name>");
    else if (args.length == 1) {  // looking for character ID
      System.out.println("Get ID for the character \"" + args[0] + "\"");
      MarvelUtils.lookupCharacterID(args[0], PUBLIC_KEY, PRIVATE_KEY);
    }
    else {   // two argument version; looking for series ID
      if (args[0].equals("series")) {
        System.out.println("Get ID for the series \"" + args[1] + "\"");
        MarvelUtils.lookupSeriesID(args[1], PUBLIC_KEY, PRIVATE_KEY);
      }
      else
        System.out.println("Do you mean \"series\" instead of  \"" + args[1] + "\"");
    }
  }  // end of main()


}  // end of GetID class
