
// GetName.java
// Andrew Davison, February 2014, ad@fivedots.coe.psu.ac.th

/*
   Find the character name or series name attached to the 
   specified ID using the Marvel API
   (http://developer.marvel.com/)

   A search for a character will return name, ID, description, and thumbnail URL.
   The name can be a partial string for the start of the name.

   A search for a series will return title, ID, description.
   The series name can be a partial string for the start of the title.


   Usage: run GetName [series] <ID>
   e.g.
     run GetName 1009382
         // juggernaut

     run GetName series 2021
          // Incredible Hulk (1962 - 1999)
  
*/

import java.io.*;
import java.util.*;



public class GetName
{
  private static final String PUBLIC_KEY = "XXXX";
  private static final String PRIVATE_KEY = "XXXX";
     /* You must first register for a free Marvel developer account at
        http://developer.marvel.com/ and obtain a public and private API keys.

        Then edit the constants PUBLIC_KEY and PRIVATE_KEY to be your keys.
     */


  public static void main(String[] args)
  {
    if ((args.length < 1) || (args.length > 2))
      System.out.println("Usage: run GetName [series] <ID>");
    else if (args.length == 1) {  // looking for character name
      System.out.println("Get name for the character ID " + args[0]);
      String nameQuery = MarvelUtils.characterIDRequest(args[0], PUBLIC_KEY, PRIVATE_KEY);
      String nameResponse = MarvelUtils.sendQuery(nameQuery);
      MarvelUtils.characterResults(nameResponse);
    }
    else {   // two argument version; looking for series name
      if (args[0].equals("series")) {
        System.out.println("Get title for the series ID " + args[1]);
        String seriesQuery = MarvelUtils.seriesIDRequest(args[1], PUBLIC_KEY, PRIVATE_KEY);
        String seriesResponse = MarvelUtils.sendQuery(seriesQuery);
        MarvelUtils.seriesResults(seriesResponse);
      }
      else
        System.out.println("Do you mean \"series\" instead of  \"" + args[1] + "\"");
    }
  }  // end of main()


}  // end of GetName class
