
// LookupComicID.java
// Andrew Davison, February 2014, ad@fivedots.coe.psu.ac.th

/* Use a comic ID to get details on a specific comic book
   from the Marvel Rest API (http://http://developer.marvel.com/)

   Usage: run LookupComicID <comic ID> [PNG image filename]
   e.g.
     run LookupComicID 6649

   Returned details include: title, issue no., on-sale date, 
                             description, thumbnail URL, ID,
                             page count, no of stories, story titles,
                             no. of creators, creator names and roles,
                             list of characters

   If the thumbnail URL exists, it is retrieved and displayed in a window
   which has a "Save" button. The image can be saved into IM_FNM, or a file
   specified by the user on the command line.
*/

import java.io.*;
import java.util.*;
import java.awt.image.*;



public class LookupComicID
{
  private static final String PUBLIC_KEY = "XXXX";
  private static final String PRIVATE_KEY = "XXXX";
     /* You must first register for a free Marvel developer account at
        http://developer.marvel.com/ and obtain a public and private API keys.

        Then edit the constants PUBLIC_KEY and PRIVATE_KEY to be your keys.
     */

  private static final String IM_FNM = "image.png";


  public static void main(String[] args)
  {
    if ((args.length < 1) || (args.length > 2)) {
      System.out.println("Usage: run LookupComicID <comic id> [PNG image filename]");
      return;
    }

    // set image filename where thumbnail can be saved
    String imFnm = IM_FNM;
    if (args.length == 2) 
      imFnm = args[1];

    String urlQuery = MarvelUtils.comicIDRequest(args[0], PUBLIC_KEY, PRIVATE_KEY);
    String response = MarvelUtils.sendQuery(urlQuery);
    String thumbAddress = MarvelUtils.comicsResults(response, true);
                        // show all the details, and get back thumb URL address

    if (thumbAddress != null) {
      BufferedImage im = MarvelUtils.downloadImage(thumbAddress);
      if (im != null) {
        System.out.println("Image size: " +  im.getWidth() + " x " + im.getHeight());
        System.out.println("Thumbnail can be saved to \"" + imFnm + "\"");
        MarvelUtils.displayImage(im, imFnm);
      }
    }
  }   // end of main()

}  // end of LookupComicID class
