
// WhichCharacters.java
// Andrew Davison, February 2014, ad@fivedots.coe.psu.ac.th

/*
   Get a list of characters who appeared in a given series
   using the Marvel Rest API (http://developer.marvel.com/)
   The series may be a partial name for the start of the
   title, or the series ID.

   Can take a long time, and will only return a maximum of 50 matches. 
   However, it will report the total number of matches.

   Each match includes: name, ID, description, and thumbnail URL

   Usage: run WhichCharacters (<series title>|<series ID>)
   e.g.
     run WhichCharacters "Journey into Mystery"
     run WhichCharacters journey

     run WhichCharacters 2032
     run WhichCharacters 1991
                   // the Avengers
*/

import java.io.*;
import java.util.*;



public class WhichCharacters
{
  private static final String PUBLIC_KEY = "XXXX";
  private static final String PRIVATE_KEY = "XXXX";
     /* You must first register for a free Marvel developer account at
        http://developer.marvel.com/ and obtain a public and private API keys.

        Then edit the constants PUBLIC_KEY and PRIVATE_KEY to be your keys.
     */


  public static void main(String[] args)
  {
    if (args.length != 1) {
      System.out.println("Usage: run WhichCharacters (<series title>|<series ID>)");
      return;
    }

    /* if the user supplied a series string, convert that into an ID.
       If there are many matching IDs, use the first one */
    String seriesID = null;
    if (!MarvelUtils.isID(args[0])) {    // user supplied a string
      System.out.println("Get ID for the series \"" + args[0] + "\"");
      seriesID = MarvelUtils.lookupSeriesID(args[0], PUBLIC_KEY, PRIVATE_KEY);
          /* there will probably be many matching series; use the first one
             in the next stage */
    }
    else
      seriesID = args[0];

    if (seriesID == null)  // no matching ID for that string, so give up
      return;
    else
      System.out.println("Using ID: " + seriesID + "\n");

    // use the series ID to search for characters
    String urlQuery = MarvelUtils.seriesCharactersRequest(seriesID, 
                                                     PUBLIC_KEY, PRIVATE_KEY);
    String response = MarvelUtils.sendQuery(urlQuery);
    MarvelUtils.characterResults(response);
  }   // end of main()


}  // end of WhichCharacters class
