
// WhichSeries.java
// Andrew Davison, February 2014, ad@fivedots.coe.psu.ac.th

/*
   Find series where a character name or ID has appeared
   using the Marvel Rest API (http://developer.marvel.com/).
   The character name can be a partial string for the start of the name.

   Can take a long time, and will only return a maximum of 50 matches. 
   However, it will report the total number of matches.

   Each match includes: title, ID, description

   Usage: run WhichSeries (<character name>|<character ID>)
   e.g.
     run WhichSeries juggernaut
     run WhichSeries spider-man
     run WhichSeries 1009382

     run WhichSeries "luke cage"
     run WhichSeries power
*/

import java.io.*;
import java.util.*;



public class WhichSeries
{
  private static final String PUBLIC_KEY = "XXXX";
  private static final String PRIVATE_KEY = "XXXX";
     /* You must first register for a free Marvel developer account at
        http://developer.marvel.com/ and obtain a public and private API keys.

        Then edit the constants PUBLIC_KEY and PRIVATE_KEY to be your keys.
     */


  public static void main(String[] args)
  {
    if (args.length != 1) {
      System.out.println("Usage: run WhichSeries (<character name>|<character ID>)");
      return;
    }


    /* if the user supplied a name string, convert that into an ID.
       If there are many matching IDs, use the first one */
    String characterID = null;
    if (!MarvelUtils.isID(args[0])) {    // not an ID, so user supplied a name string
      System.out.println("Get ID for the character \"" + args[0] + "\"");
      characterID = MarvelUtils.lookupCharacterID(args[0], PUBLIC_KEY, PRIVATE_KEY);
          /* there might be many matching character IDs; use the first one
             in the next stage */
    }
    else
      characterID = args[0];

    if (characterID == null)   // no matching ID for that string, so give up
      return;
    else
      System.out.println("Using ID: " + characterID + "\n");

    // use the character ID to search for series
    String urlQuery = MarvelUtils.characterSeriesRequest(characterID,
                                                      PUBLIC_KEY, PRIVATE_KEY);
    String response = MarvelUtils.sendQuery(urlQuery);
    MarvelUtils.seriesResults(response);
  }   // end of main()


}  // end of WhichSeries class
